@@ -1,5 +1,7 @@
 import csv
 from datetime import datetime
+import dateutil.tz
+import feedparser
 import os
 from .post import Post
 
@@ -35,7 +37,7 @@ class Home():
 
         print('\nPreparing CSV...')
         self.today = datetime.now()
-        self.csv_title = self.today.strftime('%Y-%m-%dT%H-%M') + '.csv'
+        self.csv_title = self.today.strftime('%Y-%m-%d-%H-%M') + '.csv'
         self.csv_directory = os.path.join(os.path.expanduser('~'), 'SIGACTS')
         self.csv_path = os.path.join(self.csv_directory, self.csv_title)
 
@@ -59,24 +61,48 @@ class Home():
         self.posts = []
         self.activities = []
 
+        self.feed = feedparser.parse(
+            'http://www.facebook.com/feeds/'
+            'page.php?format=atom10&id=121855461256134'
+        )
+
+        self.entered_date = input(
+            '\nPlease enter a starting time. (YYYY-MM-DD-hhmm) '
+        )
+
         while True:
-            answer = input(
-                '\nPlease enter a permalink to a post '
-                "from the Syrian Observatory for Human Rights' "
-                'Facebook page. (To finish entering posts, press Enter) '
+            self.entered_date += (
+                datetime.now(dateutil.tz.tzlocal()).strftime('%z')
             )
-            if answer == '':
-                break
-            elif answer[:40] == 'https://www.facebook.com/syriaohr/posts/':
-                self.posts.append(Post(self, answer))
-            else:
-                answer = input(
-                    '\nInvalid answer. (Please enter a link to permalink '
-                    'to a post from the '
-                    "Syrian Observatory for Human Rights' "
-                    'Facebook page, or press Enter '
-                    'to finish entering posts.) '
+
+            try:
+                self.start_date = datetime.strptime(
+                    self.entered_date, '%Y-%m-%d-%H%M%z'
                 )
+                break
+            except ValueError:
+                self.entered_date = input(
+                    '\nInvalid answer. '
+                    '(Please enter a date in YYYY-MM-DD-hhmm format) '
+                )
+
+        entries = self.feed.entries
+        entries.reverse()
+
+        self.stop = False
+        for entry in entries:
+            if self.stop:
+                break
+
+            entry_date = (
+                entry.published[::-1].replace(':'[::-1], ''[::-1], 1)[::-1]
+            )
+            entry_date = datetime.strptime(
+                entry_date, '%Y-%m-%dT%H:%M:%S%z'
+            )
+            
+            if entry_date >= self.start_date:
+                self.posts.append(Post(self, entry, entry_date))
 
         print(
             '\nSaved CSV as', self.csv_path,
